@@ -1231,7 +1231,7 @@ testBuildRelativeUri(void) {
             "/b2/c2",
             "with%20space/x%20x/y%20y"
         }
-#if defined(_WIN32) || defined(__CYGWIN__)
+#if defined(LIBXML_WINPATH_ENABLED)
         , {
             "\\a\\b1\\c1",
             "\\a\\b2\\c2",
@@ -1298,7 +1298,7 @@ testBuildRelativeUri(void) {
     return err;
 }
 
-#if defined(_WIN32) || defined(__CYGWIN__)
+#if defined(LIBXML_WINPATH_ENABLED)
 static int
 testWindowsUri(void) {
     const char *url = "c:/a%20b/file.txt";
@@ -1371,7 +1371,7 @@ testWindowsUri(void) {
 
     return err;
 }
-#endif /* WIN32 */
+#endif /* LIBXML_WINPATH_ENABLED */
 
 #if defined(LIBXML_ICONV_ENABLED) || defined(LIBXML_ICU_ENABLED)
 static int
@@ -1530,6 +1530,68 @@ testCharEncConvImpl(void) {
     return err;
 }
 
+static int
+testRemoveParamEntityIntSubset(void) {
+    xmlDocPtr doc;
+    xmlEntityPtr ent;
+    int err = 0;
+
+    doc = xmlNewDoc(BAD_CAST "1.0");
+    xmlCreateIntSubset(doc, BAD_CAST "doc", NULL, NULL);
+
+    xmlAddDocEntity(doc, BAD_CAST "param1", XML_INTERNAL_PARAMETER_ENTITY,
+                    NULL, NULL, BAD_CAST "value");
+    ent = xmlGetParameterEntity(doc, BAD_CAST "param1");
+    if (ent == NULL) {
+        fprintf(stderr, "testRemoveParamEntityIntSubset: "
+                "entity not found after add\n");
+        xmlFreeDoc(doc);
+        return 1;
+    }
+    xmlUnlinkNode((xmlNodePtr) ent);
+    if (xmlGetParameterEntity(doc, BAD_CAST "param1") != NULL) {
+        fprintf(stderr, "testRemoveParamEntityIntSubset: "
+                "parameter entity still in pentities after unlink\n");
+        err = 1;
+    } else {
+        xmlFreeNode((xmlNodePtr) ent);
+    }
+    xmlFreeDoc(doc);
+
+    return err;
+}
+
+static int
+testRemoveParamEntityExtSubset(void) {
+    xmlDocPtr doc;
+    xmlEntityPtr ent;
+    int err = 0;
+
+    doc = xmlNewDoc(BAD_CAST "1.0");
+    xmlNewDtd(doc, BAD_CAST "doc", NULL, BAD_CAST "doc.dtd");
+
+    xmlAddDtdEntity(doc, BAD_CAST "param2", XML_EXTERNAL_PARAMETER_ENTITY,
+                    NULL, NULL, BAD_CAST "value");
+    ent = xmlGetParameterEntity(doc, BAD_CAST "param2");
+    if (ent == NULL) {
+        fprintf(stderr, "testRemoveParamEntityExtSubset: "
+                "entity not found after add\n");
+        xmlFreeDoc(doc);
+        return 1;
+    }
+    xmlUnlinkNode((xmlNodePtr) ent);
+    if (xmlGetParameterEntity(doc, BAD_CAST "param2") != NULL) {
+        fprintf(stderr, "testRemoveParamEntityExtSubset: "
+                "parameter entity still in pentities after unlink\n");
+        err = 1;
+    } else {
+        xmlFreeNode((xmlNodePtr) ent);
+    }
+    xmlFreeDoc(doc);
+
+    return err;
+}
+
 int
 main(void) {
     int err = 0;
@@ -1584,13 +1646,15 @@ main(void) {
     err |= testWriterClose();
 #endif
     err |= testBuildRelativeUri();
-#if defined(_WIN32) || defined(__CYGWIN__)
+#if defined(LIBXML_WINPATH_ENABLED)
     err |= testWindowsUri();
 #endif
 #if defined(LIBXML_ICONV_ENABLED) || defined(LIBXML_ICU_ENABLED)
     err |= testTruncatedMultiByte();
 #endif
     err |= testCharEncConvImpl();
+    err |= testRemoveParamEntityIntSubset();
+    err |= testRemoveParamEntityExtSubset();
 
     return err;
 }
